<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Torna enrere"; break;
case "Privilegi dell'utente":  			$messaggio = "Privilegis de l'usuari"; break;
case "Privilegi <b>globali</b>":  		$messaggio = "Privilegis <b>globals</b>"; break;
case "Modifica delle proprie personalizzazioni":	$messaggio = "Modificació de les pròpies personalitzacions"; break;
case "Si":  					$messaggio = "Sí"; break;
case "No":  					$messaggio = "No"; break;
case "Inserimento di nuovi clienti":  		$messaggio = "Inserció de nous clients"; break;
case "Possibilità di vedere ed utilizzare nelle prenotazioni i clienti già inseriti":	$messaggio = "Possibilitat de veure i emprar a les reserves els clients ja inserits"; break;
case "Solo":  					$messaggio = "Solo"; break;
case "i propri":  				$messaggio = "els propis"; break;
case "Modifica e cancellazione dei clienti già inseriti":  	$messaggio = "Modificació i supressió dels clients ja inserits"; break;
case "dei propri":  				$messaggio = "dels propis"; break;
case "Inserire in tutti i cognomi dei clienti inseriti da questo utente":	$messaggio = "Insertar en tots els cognoms dels clients inserits por este usuari"; break;
case "Un prefisso":  				$messaggio = "Un prefix"; break;
case "Un suffisso":  				$messaggio = "Un sufix"; break;
case "Niente":  				$messaggio = "Res"; break;
case "Modifica i privilegi globali":  		$messaggio = "Modificals privilegis globals"; break;
case "Privilegi per l'anno":			$messaggio = "Privilegis per l'any"; break;
case "Anno disattivato":  			$messaggio = "Ani desactivat"; break;
case "Attiva":  				$messaggio = "Activa"; break;
case "Anno attivato":  				$messaggio = "Ani activat"; break;
case "Disattiva":  				$messaggio = "Desactiva"; break;
case "Prenotazioni inseribili solo nei periodi della regola di assegnazione 1 con le motivazioni selezionate":	$messaggio = "Reserves inseribles només als períodes de la regla d'assignació 1 amb els motius seleccionats"; break;
case "nessuna":  				$messaggio = "cap"; break;
case "Applica la regola 1":  			$messaggio = "Aplica la regla 1"; break;
case "Sempre":  				$messaggio = "Sempre"; break;
case "Solo per regole non selezionate":  	$messaggio = "Només per regles no seleccionades"; break;
case "Mai":  					$messaggio = "Mai"; break;
case "Mai, ma non spostare altre prenotazioni in periodi delle regole non selezionate se non vi si possono inserire prenotazioni":	$messaggio = "Mai, però no desplaçar d'altres reserves a períodes de les regles no seleccionades si no s'hi poden inserir reserves"; break;
case "Permetti l'uso di tutte le <i>tariffe</i> nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permetre emprar totes les <i>tarifes</i> quan s'insereixin o modifiquin reserves"; break;
case "Permetti l'uso solo delle <i>tariffe</i> selezionate nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permetre emprar només les <i>tarifes</i> seleccionades quan s'insereixin o modifiquin reserves"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "Permetti l'uso di tutti i <i>costi aggiuntivi</i> nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permetre emprar tots els <i>suplements</i> quan s'insereixin o modifiquin reserves"; break;
case "Permetti l'uso solo dei <i>costi aggiuntivi</i> selezionati nell'inserimento e modifica delle prenotazioni":	$messaggio = "Permetre emprar només els <i>suplements</i> seleccionats quan s'insereixin o modifiquin reserves"; break;
case "Costo unico":  				$messaggio = "Coste puntual"; break;
case "Costo settimanale":  			$messaggio = "Coste setmanal"; break;
case "Costo giornaliero":  			$messaggio = "Coste diari"; break;
case "Permetti la visualizzazione di tutti i <i>documenti</i>":	$messaggio = "Permetre mostrar tots els <i>documents</i>"; break;
case "Permetti la visualizzazione solo dei <i>documenti</i> selezionati":	$messaggio = "Permetre mostrar només els <i>documents</i> seleccionats"; break;
case "Non permettere l'inserimento di <i>nuove prenotazioni</i>":	$messaggio = "No permetre la inserció de <i>noves reserves</i>"; break;
case "Permetti l'inserimento di <i>nuove prenotazioni</i> con le seguenti possibilità":	$messaggio = "Permetre la inserció de <i>noves reserves</i> amb les següents possibilitats"; break;
case "Possibilità di confermare la prenotazione":	$messaggio = "Possibilitat de confirmar la reserva"; break;
case "Possibilità di inserire uno sconto":  	$messaggio = "Possibilitat d'inserir un descompte"; break;
case "Possibilità di inserire la caparra e le commissioni":  	$messaggio = "Possibilitat d'inserir arres i comissions"; break;
case "Possibilità di inserire dei costi aggiuntivi":	$messaggio = "Possibilitat d'inserir suplements"; break;
case "Possibilità di inserire il numero di persone":	$messaggio = "Possibilitat d'inserir el número de persones"; break;
case "Possibilità di inserire prenotazioni anche in periodi già iniziati":	$messaggio = "Possibilitat d'inserir reserves també a períodes ja començats"; break;
case "Prenotazioni che possono essere <i>modificate</i>":	$messaggio = "Reserves que pueden ésser <i>modificades</i>"; break;
case "Tutte":  					$messaggio = "Totes"; break;
case "le proprie":  				$messaggio = "les pròpies"; break;
case "dei suoi gruppi":  			$messaggio = "dels seus grups"; break;
case "Nessuna":  				$messaggio = "Cap"; break;
case "Possibilità di modificare la data iniziale o finale":	$messaggio = "Possibilitat de modificar la data d'arribada o de sortida"; break;
case "Possibilità di modificare la tariffa":  	$messaggio = "Possibilitat de modificar la tarifa"; break;
case "Si, con regola 2 a scelta":  		$messaggio = "Sí, i opcionalment seguint la regla 2"; break;
case "Si, sempre con regola 2":  		$messaggio = "Sí, sempre amb la regla 2"; break;
case "Possibilità di modificare il numero delle persone":	$messaggio = "Possibilitat de modificar el número de persones"; break;
case "Possibilità di modificare il commento":  	$messaggio = "Possibilitat de modificar el comentari"; break;
case "Possibilità di modificare lo sconto":  	$messaggio = "Possibilitat de modificar el descompte"; break;
case "Possibilità di modificare la caparra e le commissioni":	$messaggio = "Possibilitat de modificar arres i comissions"; break;
case "Possibilità di modificare i costi aggiuntivi":	$messaggio = "Possibilitat de modificar els suplements"; break;
case "Possibilità di modificare i soldi pagati e la conferma":	$messaggio = "Possibilitat de modificar l'import pagat i la confirmació"; break;
case "Solo la conferma":  			$messaggio = "Només la Confirmació"; break;
case "Possibilità di modificare prenotazioni già iniziate":	$messaggio = "Possibilitat de modificar reserves ja iniciades"; break;
case "Prenotazioni non più modificabili dopo un certo numero di ore dopo l'inserzione":	$messaggio = "Reserves ja no modificables després d'unes hores determinades un cop inserida la reserva"; break;
case "ore":  					$messaggio = "hores"; break;
case "Possibilità di cancellare le prenotazioni":	$messaggio = "Possibilitat d'esborrar la reserva"; break;
case "Solo quelle non iniziate":  		$messaggio = "Només les no començades"; break;
case "Prenotazioni non più cancellabili dopo un certo numero di ore dopo l'inserzione":	$messaggio = "Reserves ja no esborrables després d'unes hores determinades un cop inserida la reserva"; break;
case "Possibilità di inserire e cancellare le <i>spese</i>":	$messaggio = "Possibilitat d'inserir i esborrar les <i>despeses</i>"; break;
case "Possibilità di inserire e cancellare le <i>entrate</i>":	$messaggio = "Possibilitat d'inserir i esborrar els <i>ingressos</i>"; break;
case "<i>Sottrarre le entrate</i> dal totale delle prenotazioni":	$messaggio = "<i>No sumar els ingressos</i> als ingressos provinents de les reserves"; break;
case "A scelta":  				$messaggio = "Demanar"; break;
case "Immettere come <i>persona</i> che inserisce le spese o le entrate":	$messaggio = "Mostrar com a <i>persona</i> que insereix les despeses o els ingressos"; break;
case "Il nome dell'utente":  			$messaggio = "El nom de l'usuari"; break;
case "Chiedere":  				$messaggio = "Demanar"; break;
case "Nessuno":  				$messaggio = "Ningú"; break;
case "Possibilità di vedere la <i>tabella dei mesi</i>":	$messaggio = "Possibilitat de veure el <i>planning per mesos</i>"; break;
case "Solo con":				$messaggio = "Només amb"; break;
case "prenotazioni proprie":			$messaggio = "reserves pròpies"; break;
case "prenotazioni dai suoi gruppi":		$messaggio = "reserves dels seus grups"; break;
case "a lui":					$messaggio = "a ell mateix"; break;
case "ai suoi gruppi":				$messaggio = "als seus grups"; break;
case "Possibilità di vedere la <i>tabella con tutte le prenotazioni</i>":	$messaggio = "Possibilitat de veure la <i>taula amb totes les reserves</i>"; break;
case "Possibilità di vedere le <i>tabelle con le entrate e le uscite</i>":	$messaggio = "Possibilitat de veure la <i>taula amb les despeses i els ingressos</i>"; break;
case "entrate/uscite proprie":  		$messaggio = "despeses/ingressos propis"; break;
case "entrate/uscite dai suoi gruppi":  	$messaggio = "despeses/ingressos dels seus grups"; break;
case "Possibilità di vedere la <i>tabella con i periodi e le tariffe</i>":	$messaggio = "Possibilitat de veure la <i>taula amb les temporades i les tarifes</i>"; break;
case "Solo con tariffe consentite":  		$messaggio = "Solo con tarifes permeses"; break;
case "Possibilità di vedere la <i>tabella con le regole di assegnazione</i>":	$messaggio = "Possibilitat de veure la <i>taula amb les regles d'assignació</i>"; break;
case "Solo con regole consentite":  		$messaggio = "Només amb regles permeses"; break;
case "Modifica i privilegi dell'anno":  	$messaggio = "Modificals privilegis de l'any"; break;
case "Testo del prefisso/suffisso dei clienti":	$messaggio = "Text del prefix/sufix dels clients"; break;
case "Si deve inserire il <div style=\"display: inline; color: red;\">prefisso/suffisso</div> da utilizzare per i clienti dell'utente":	$messaggio = "Cal inserir el <div style=\"display: inline; color: red;\">prefix/sufix</div> a emprar pels clients de l'usuari"; break;
case "L'utente":  				$messaggio = "L'usuari"; break;
case "potrà modificare le sue <b>personalizzazioni</b>":	$messaggio = "podrà modificar les seves <b>personalitzacions</b>"; break;
case "non potrà più modificare le sue <b>personalizzazioni</b>":	$messaggio = "ja no podrà modificar sus <b>personalitzacions</b>"; break;
case "potrà inserire <b>nuovi clienti</b>":  	$messaggio = "podrà inserir <b>nous clients</b>"; break;
case "non potrà più inserire <b>nuovi clienti</b>":	$messaggio = "ja no podrà inserir <b>nous clients</b>"; break;
case "potrà modificare <b>tutti i clienti</b>":	$messaggio = "podrà modificar <b>tots els clients</b>"; break;
case "potrà modificare solo i <b>propri clienti</b>":	$messaggio = "podrà modificar només els seus <b>propis clients</b>"; break;
case "e quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "i els d'usuaris que pertanyin als seus grups"; break;
case "non potrà più modificare <b>nessun cliente</b>":	$messaggio = "ja no podrà modificar <b>cap client</b>"; break;
case "non potrà vedere <b>nessun cliente</b>":	$messaggio = "no podrà veure <b>cap client</b>"; break;
case "potrà vedere solo i <b>propri clienti</b>":	$messaggio = "podrà veure només els seus <b>propis clients</b>"; break;
case "potrà vedere <b>tutti i clienti</b>":  	$messaggio = "podrà veure <b>tots els clients</b>"; break;
case "Verrà aggiunto un <b>prefisso</b> a tutti i cognomi dei clienti inseriti dall'utente":	$messaggio = "s'afegirà un <b>prefix</b> a tots els cognoms dels clients inserits per l'usuari"; break;
case "Verrà aggiunto un <b>suffisso</b> a tutti i cognomi dei clienti inseriti dall'utente":	$messaggio = "s'afegirà un <b>sufix</b> a tots els cognoms dels clients inserits per l'usuari"; break;
case "Non verrà aggiunto più alcun <b>prefisso/suffisso</b> ai cognomi dei clienti inseriti dall'utente":	$messaggio = "ja no s'afegirà cap <b>prefix/sufix</b> a tots els cognoms dels clients inserits per l'usuari"; break;
case "Il nuovo testo del <b>prefisso/suffisso</b> dei cognomi dei clienti inseriti dall'utente":	$messaggio = "El nou text del <b>prefix/sufix</b> dels clients inserits per l'usuari"; break;
case "sarà":  					$messaggio = "serà"; break;
case "Continua":  				$messaggio = "Continua"; break;
case "Anno <div style=\"display: inline; color: red;\">errato</div>":	$messaggio = "Ani <div style=\"display: inline; color: red;\">erroni</div>"; break;
case "Ore in cui si può modificare la prenotazione <div style=\"display: inline; color: red;\">errate</div>":	$messaggio = "Hores a les quals es pot modificar la reserva <div style=\"display: inline; color: red;\">errònies</div>"; break;
case "Ore in cui si può cancellare la prenotazione <div style=\"display: inline; color: red;\">errate</div>":	$messaggio = "Hores a les quals es pot esborrar la reserva <div style=\"display: inline; color: red;\">errònies</div>"; break;
case "potrà inserire le sue prenotazioni in <b>tutti i periodi</b> del":	$messaggio = "podrà inserir les seves reserves a <b>tots els períodes</b> del"; break;
case "potrà inserire le sue prenotazioni solo nei <b>periodi della regola 1</b> selezionati nel":	$messaggio = "podrà inserir les seves reserves només als <b>períodes de la regla 1</b> seleccionats del"; break;
case "Verranno cambiate le motivazioni selezionate della <b>regola 1</b> per l'anno":	$messaggio = "Es canviaran les causes seleccionades de la regla 1 per l'any"; break;
case "se non vi può inserire prenotazioni":	$messaggio = "si no s'hi pot inserir reserves"; break;
case "potrà utilizzare <b>tutte le tariffe</b> del":	$messaggio = "podrà emprar <b>totes les tarifes</b> del"; break;
case "potrà utilizzare solo le <b>tariffe selezionate</b> del":	$messaggio = "podrà emprar només les <b>tarifes seleccionades</b> del"; break;
case "Verranno cambiate le <b>tariffe selezionate</b> da utilizzare per l'anno":	$messaggio = "Es canviaran les <b>tarifes seleccionades</b> a emprar per l'any"; break;
case "potrà utilizzare <b>tutti i costi aggiuntivi</b> del":	$messaggio = "podrà emprar <b>tots els suplements</b> del"; break;
case "potrà utilizzare solo i <b>costi aggiuntivi selezionati</b> del":	$messaggio = "podrà emprar només els <b>suplements seleccionats</b> del"; break;
case "Verranno cambiati i <b>costi aggiuntivi</b> da utilizzare per l'anno":	$messaggio = "Es canviaran els <b>suplements seleccionats</b> a emprar per l'any"; break;
case "potrà visualizzare <b>tutti i documenti</b> del":	$messaggio = "podrà mostrar <b>tots els documents</b> del"; break;
case "potrà visualizzare solo i <b>documenti selezionati</b> del":	$messaggio = "podrà mostrar només els <b>documents seleccionats</b> del"; break;
case "Verranno cambiati i <b>documenti</b> visualizzabili per l'anno":	$messaggio = "Es canviaran les <b>documents seleccionats</b> a mostrar per l'any"; break;
case "non potrà inserire <b>nuove prenotazioni</b> nel":	$messaggio = "no podrà inserir <b>noves reserves</b> al"; break;
case "potrà inserire <b>nuove prenotazioni</b> nel":	$messaggio = "podrà inserir <b>noves reserves</b> al"; break;
case "non potrà <b>confermare</b> le nuove prenotazioni inserite nel":	$messaggio = "no podrà <b>confirmar</b> les noves reserves inserides al"; break;
case "potrà <b>confermare</b> le nuove prenotazioni inserite nel":	$messaggio = "podrà <b>confirmar</b> les noves reserves inserides al"; break;
case "non potrà inserire nuove prenotazioni in <b>periodi già iniziati</b> nel":	$messaggio = "no podrà inserir noves reserves en <b>períodes ja començats</b> al"; break;
case "potrà inserire nuove prenotazioni in <b>periodi già iniziati</b> nel":	$messaggio = "podrà inserir noves reserves en <b>períodes ja començats</b> al"; break;
case "non potrà modificare <b>nessuna prenotazione</b> nel":	$messaggio = "no podrà modificar <b>cap reserva</b> al"; break;
case "potrà modificare solo le <b>sue prenotazioni</b> nel":	$messaggio = "podrà modificar només <b>les seves reserves</b> al"; break;
case "potrà modificare solo le <b>sue prenotazioni</b> e quelle di utenti appartenenti ai suoi gruppi nel":	$messaggio = "podrà modificar només <b>les seves reserves</b> i les d'usuaris que pertanyin als seus grups al"; break;
case "potrà modificare <b>tutte le prenotazioni</b> nel":	$messaggio = "podrà modificar <b>totes les reserves</b> al"; break;
case "non potrà modificare la <b>data iniziale o finale</b> delle prenotazioni nel":	$messaggio = "no podrà modificar la <b>data d'arribada o de sortida</b> de les reserves al"; break;
case "potrà modificare la <b>data iniziale o finale</b> delle prenotazioni nel":	$messaggio = "podrà modificar la <b>data d'arribada o de sortida</b> de les reserves al"; break;
case "non potrà modificare la <b>tariffa</b> delle prenotazioni nel":	$messaggio = "no podrà modificar la <b>tarifa</b> de les reserves al"; break;
case "potrà modificare la <b>tariffa</b> delle prenotazioni, scegliendo se utilizzare la regola 2, nel":	$messaggio = "podrà modificar la <b>tarifa</b> de les reserves, escollint si emprar la regla 2, al"; break;
case "non potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "no podrà modificar el <b>número de les persones</b> de les reserves al"; break;
case "potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "podrà modificar el <b>número de les persones</b> de les reserves al"; break;
case "non potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "no podrà modificar el <b>comentari</b> de les reserves al"; break;
case "potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "podrà modificar el <b>comentari</b> de les reserves al"; break;
case "non potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "no podrà modificar el <b>descompte</b> de les reserves al"; break;
case "potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "podrà modificar el <b>descompte</b> de les reserves al"; break;
case "non potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "no podrà modificar <b>arres</b> ni <b>comissions</b> de les reserves al"; break;
case "potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "podrà modificar <b>arres</b> i <b>comissions</b> de les reserves al"; break;
case "non potrà modificare i <b>costi aggiuntivi</b> delle prenotazioni nel":	$messaggio = "no podrà modificar els <b>suplements</b> de les reserves al"; break;
case "potrà modificare i <b>costi aggiuntivi</b> delle prenotazioni nel":	$messaggio = "podrà modificar els <b>suplements</b> de les reserves al"; break;
case "non potrà modificare i <b>soldi pagati</b> e la <b>conferma</b> delle prenotazioni nel":	$messaggio = "no podrà modificar l'<b>import pagat</b> ni la <b>confirmació</b> de les reserves al"; break;
case "non potrà modificare i <b>soldi pagati</b> ma solo la <b>conferma</b> delle prenotazioni nel":	$messaggio = "no podrà modificar l'<b>import pagat</b> sinó només la <b>confirmació</b> de les reserves al"; break;
case "potrà modificare i <b>soldi pagati</b> e la <b>conferma</b> delle prenotazioni nel":	$messaggio = "podrà modificar l'<b>import pagat</b> i la <b>confirmació</b> de les reserves al"; break;
case "non potrà modificare le <b>prenotazioni già iniziate</b> nel":	$messaggio = "no podrà modificar les <b>reserves actuals</b> al"; break;
case "potrà modificare anche le <b>prenotazioni già iniziate</b> nel":	$messaggio = "podrà modificar les <b>reserves actuals</b> al"; break;
case "non avrà <b>limite di tempo</b> per modificare le prenotazioni nel":	$messaggio = "no tindrà <b>límit de temps</b> per modificar les reserves al"; break;
case "non potrà più modificare le prenotazioni <b>dopo":	$messaggio = "no podrà modificar les reserves <b>després de"; break;
case "non potrà <b>cancellare</b> nessuna prenotazione nel":	$messaggio = "no podrà <b>esborrar</b> cap reserva al"; break;
case "potrà <b>cancellare</b> tutte le prenotazioni nel":	$messaggio = "podrà <b>esborrar</b> totes les reserves al"; break;
case "non avrà <b>limite di tempo</b> per cancellare le prenotazioni nel":	$messaggio = "no tindrà <b>límit de temps</b> per esborrar les reserves al"; break;
case "ore</b> nel":  				$messaggio = "hores</b> al"; break;
case "non potrà più cancellare le prenotazioni <b>dopo":	$messaggio = "no podrà esborrar les reserves <b>després de"; break;
case "non potrà inserire le <b>spese</b> nel":	$messaggio = "no podrà inserir <b>despeses</b> al"; break;
case "potrà inserire le <b>spese</b> nel":  	$messaggio = "podrà inserir <b>despeses</b> al"; break;
case "non potrà inserire le <b>entrate</b> nel":	$messaggio = "no podrà inserir <b>ingressos</b> al"; break;
case "potrà inserire le <b>entrate</b> nel":	$messaggio = "podrà inserir <b>ingressos</b> al"; break;
case "Le entrate inserite non verranno mai <b>sottratte</b> dal totale delle prenotazioni nel":	$messaggio = "Els ingressos inserits no seran mai <b>bestrets</b> de l'import global de les reserves al"; break;
case "potrà decidere se <b>sottrarre</b> le entrate dal totale delle prentazioni nel":	$messaggio = "podrà decidir si <b>bestreure</b> els ingressos de l'import global de les reserves al"; break;
case "Le entrate inserite verranno sempre <b>sottratte</b> dal totale delle prenotazioni nel":	$messaggio = "Els ingressos inserits seran sempre <b>bestrets</b> de l'import global de les reserves al"; break;
case "Non verrà inserito nessuno come <b>persona</b> che inserisce le spese o le entrate nel":	$messaggio = "No s'enregistrarà ningú com a <b>persona</b> que insereix les despeses o els ingressos al"; break;
case "potrà scegliere chi inserire come <b>persona</b> che inserisce le spese e le entrate nel":	$messaggio = "podrà escollir qui enregistrar com a <b>persona</b> que insereix les despeses o els ingressos al"; break;
case "Verrà sempre inserito il nome dell'utente":	$messaggio = "S'inserirà sempre el nom de l'usuari"; break;
case "come <b>persona</b> che inserisce le spese e le entrate nel": 	$messaggio = "com a <b>persona</b> que insereix les despeses o els ingressos al"; break;
case "non potrà vedere le <b>tabelle dei mesi</b> del":	$messaggio = "no podrà veure el <b>planning per mesos</b> del"; break;
case "nelle <b>tabelle dei mesi</b> del":  	$messaggio = "al <b>planning per mesos</b> del"; break;
case "potrà vedere le <b>tabelle dei mesi</b> del":	$messaggio = "podrà veure el <b>planning per mesos</b> del"; break;
case "non potrà vedere la <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "no podrà veure la <b>taula amb totes les reserves</b> del"; break;
case "potrà vedere solo le proprie prenotazioni nella <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "podrà veure només les seves pròpies reserves a la <b>taula amb totes les reserves</b> del"; break;
case "potrà vedere solo le prenotazioni sue e di utenti appartenenti ai suoi gruppi nella <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "podrà veure només les seves reserves i les d'usuaris que pertanyin als seus grups a la <b>taula amb totes les reserves</b> del"; break;
case "potrà vedere la <b>tabella con tutte le prenotazioni</b> del":	$messaggio = "podrà veure la <b>taula amb totes les reserves</b> del"; break;
case "non potrà vedere le <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "no podrà veure les <b>taules amb les despeses i els ingressos</b> del"; break;
case "potrà vedere solo le proprie entrate/uscite nelle <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "podrà veure només els seus propis ingressos/despeses a les <b>taules amb les despeses i els ingressos</b> del"; break;
case "potrà vedere solo le entrate/uscite sue e di utenti appartenenti ai suoi gruppi nelle <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "podrà veure només els seus ingressos/despeses i els d'usuaris que pertanyin als seus grups a les <b>taules amb les despeses i els ingressos</b> del"; break;
case "potrà vedere le <b>tabelle con le entrate e le uscite</b> del":	$messaggio = "podrà veure les <b>taules amb les despeses i els ingressos</b> del"; break;
case "non potrà vedere la <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "no podrà veure la <b>taula amb les temporades i les tarifes</b> del"; break;
case "potrà vedere solo le tariffe a lui consentite nella <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "podrà veure només les tarifesque li siguin permeses a la <b>taula amb les temporades i les tarifes</b> del"; break;
case "potrà vedere solo le tariffe consentite a lui e ad utenti dei suoi gruppi nella <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "podrà veure només les tarifes que li siguin permeses a ell i a d'altres usuaris dels seus grups a la <b>taula amb les temporades i les tarifes</b> del"; break;
case "potrà vedere la <b>tabella con i periodi e le tariffe</b> del":	$messaggio = "podrà veure la <b>taula amb les temporades i les tarifes</b> del"; break;
case "non potrà vedere la <b>tabella con le regole di assegnazione</b> del":	$messaggio = "no podrà veure la <b>taula amb les regles d'assignació</b> del"; break;
case "potrà vedere solo le regole a lui consentite nella <b>tabella con le regole di assegnazione</b> del":	$messaggio = "podrà veure només les regles que li siguin permeses a la <b>taula amb les regles d'assignació</b> del"; break;
case "potrà vedere solo le regole consentite a lui e ad utenti dei suoi gruppi nella <b>tabella con le regole di assegnazione</b> del":	$messaggio = "podrà veure només les regles que li siguin permeses a ell i a d'altres usuaris dels seus grups a la <b>taula amb les regles d'assignació</b> del"; break;
case "potrà vedere la <b>tabella con le regole di assegnazione</b> del":	$messaggio = "podrà veure la <b>taula amb les regles d'assignació</b> del"; break;
case "Possibilità di inserire più prenotazioni contemporaneamente":	$messaggio = "Possibilitat d'inserir vàries reserves simultàniament"; break;
case "non potrà inserire <b>più prenotazioni contemporaneamente</b> nel":	$messaggio = "no podrà inserir <b>vàries reserves simultàniament</b> al"; break;
case "potrà inserire <b>più prenotazioni contemporaneamente</b> nel":	$messaggio = "podrà inserir <b>vàries reserves simultàniament</b> al"; break;
case "Prenotazioni non più cancellabili dopo essere state confermate":	$messaggio = "Les reserves no són esborrables després d'haver estat confirmades"; break;
case "non potrà <b>cancellare</b> le prenotazioni confermate nel":	$messaggio = "no podrà <b>esborrar</b> les reserves confirmades al"; break;
case "potrà <b>cancellare</b> le prenotazioni confermate nel":	$messaggio = "podrà <b>esborrar</b> les reserves confirmades al"; break;
case "Possibilità di modificare l'orario di entrata ed uscita":	$messaggio = "Possibilitat de modificar l'horari d'arribada i sortida"; break;
case "non potrà modificare l'orario di <b>entrata ed uscita</b> delle prenotazioni nel":	$messaggio = "no podrà modificar l'<b>horari d'arribada ni de sortida</b> de les reserves al"; break;
case "potrà modificare l'orario di <b>entrata ed uscita</b> delle prenotazioni nel":	$messaggio = "podrà modificar l'<b>horari d'arribada i de sortida</b> de les reserves al"; break;
case "Possibilità di vedere i messaggi ricevuti":	$messaggio = "Possibilitat de veure els missatges rebuts"; break;
case "Possibilità di mandare messaggi":  	$messaggio = "Possibilitat d'enviar missatges"; break;
case "non potrà vedere <b>i messaggi ricevuti</b>":	$messaggio = "no podrà veure <b>els missatges rebuts</b>"; break;
case "potrà vedere <b>i messaggi ricevuti</b>":	$messaggio = "podrà veure <b>els missatges rebuts</b>"; break;
case "non potrà <b>inviare messaggi</b>":	$messaggio = "no podrà <b>enviar missatges</b>"; break;
case "potrà <b>inviare messaggi</b>":  		$messaggio = "podrà <b>enviar missatges</b>"; break;
case "Possibilità di inserire l'orario di entrata":	$messaggio = "Possibilitat d'inserir l'horari d'arribada"; break;
case "non potrà vedere e modificare il <b>codice prenotazione</b> nel":	$messaggio = "no podrà veure ni modificar el <b>codi de reserva</b> al"; break;
case "potrà vedere e modificare il <b>codice prenotazione</b> nel":	$messaggio = "podrà veure i modificar el <b>codi de reserva</b> al"; break;
case "Possibilità di vedere e modificare il codice prenotazione":	$messaggio = "Possibilitat de veure i modificar el codi de reserva"; break;
case "Possibilità di cambiare il cliente con un altro":	$messaggio = "Possibilitat de canviar el cliente con otro"; break;
case "potrà cambiare il <b>cliente</b> delle prenotazioni nel":	$messaggio = "podrà canviar el <b>cliente</b> de les reserves al"; break;
case "non potrà cambiare il <b>cliente</b> delle prenotazioni nel":	$messaggio = "no podrà canviar el <b>cliente</b> de les reserves al"; break;
case "potrà inserire <b>più prenotazioni contemporaneamente ma non vicine</b> nel":	$messaggio = "podrà inserir <b>vàries reserves simultèniament però podran ésser properes</b> al"; break;
case "Possibilità di modificare le prenotazioni vicine":	$messaggio = "Possibilitat de modificar les reserves properes"; break;
case "non potrà modificare le <b>prenotazioni vicine</b> nel":	$messaggio = "no podrà modificar les <b>reserves properes</b> al"; break;
case "potrà modificare le <b>prenotazioni vicine</b> nel":	$messaggio = "podrà modificar les <b>reserves properes</b> al"; break;
case "Possibilità di inserire l'origine":  	$messaggio = "Possibilitat d'inserir l'origen"; break;
case "Possibilità di modificare l'origine":  	$messaggio = "Possibilitat de modificar l'origen"; break;
case "potrà modificare il <b>l'origine</b> delle prenotazioni nel":	$messaggio = "podrà canviar l'<b>origen</b> de les reserves al"; break;
case "non potrà modificare <b>l'origine</b> delle prenotazioni nel":	$messaggio = "no podrà canviar l'<b>origen</b> de les reserves al"; break;
case "Possibilità di modificare le <i>tariffe</i> a lui permesse":	$messaggio = "Possibilitat de modificar les <i>tarifes</i> que li siguin permeses"; break;
case "Possibilità di inserire <i>nuovi costi aggiuntivi</i>":	$messaggio = "Possibilitat d'inserir <i>nous suplements</i>"; break;
case "rendendoli disponibili":			$messaggio = "fent-los disponibles"; break;
case "solo a lui":  				$messaggio = "només a ell mateix"; break;
case "a utenti dei suoi gruppi":  		$messaggio = "als usuaris dels seus grups"; break;
case "Possibilità di modificare i <i>costi aggiuntivi</i> a lui permessi":	$messaggio = "Possibilitat de modificar els <i>suplements</i> que li siguin permesos"; break;
case "non potrà modifcare le <b>tariffe a lui permesse</b> nel":	$messaggio = "no podrà modificar les <b>tarifes que li siguin permeses</b> al"; break;
case "potrà modifcare le <b>tariffe a lui permesse</b> nel":	$messaggio = "podrà modificar les <b>tarifes que li siguin permeses</b> al"; break;
case "non potrà inserire <b>nuovi costi aggiuntivi</b> nel":	$messaggio = "no podrà inserir <b>nous suplements</b> al"; break;
case "potrà inserire <b>nuovi costi aggiuntivi</b> il cui utilizzo sarà permesso a lui e agli utenti appartenenti ai suoi stessi gruppi nel":	$messaggio = "podrà inserir <b>nous suplements</b> l'ús del qual li serà permès només a ell mateix i als usuaris que pertanyin als seus grups al"; break;
case "potrà inserire <b>nuovi costi aggiuntivi</b> il cui utilizzo sarà permesso solo a lui nel":	$messaggio = "podrà inserir <b>nous suplements</b> l'ús del qual serà permès només a ell mateix al"; break;
case "non potrà modifcare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "no podrà modificar els <b>suplements</b> que li siguin permesos al"; break;
case "potrà modifcare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "podrà modificar els <b>suplements</b> que li siguin permesos al"; break;
case "Possibilità di cancellare i <i>costi aggiuntivi</i> a lui permessi":	$messaggio = "Possibilitat d'esborrar els <i>suplements</i> que li siguin permesos"; break;
case "non potrà cancellare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "no podrà esborrar els <b>suplements</b> que li siguin permesos al"; break;
case "potrà cancellare i <b>costi aggiuntivi lui permessi</b> nel":	$messaggio = "podrà esborrar els <b>suplements</b> que li siguin permesos al"; break;
case "nelle <b>statistiche</b> del":  		$messaggio = "a les <b>estadístiques</b> del"; break;
case "non potrà vedere le <b>statistiche</b> del":	$messaggio = "no podrà veure les <b>estadístiques</b> del"; break;
case "potrà vedere le <b>statistiche</b> del":	$messaggio = "podrà veure les <b>estadístiques</b> del"; break;
case "Possibilità di vedere <i>le statistiche</i>":	$messaggio = "Possibilitat de veure <i>les estadístiques</i>"; break;
case "Possibilità di vedere i <i>beni dell'inventario</i>":	$messaggio = "Possibilitat de veure els <i>béns de l'inventari</i>"; break;
case "Possibilità di inserire nuovi beni nell'inventario":	$messaggio = "Possibilitat d'inserir nous béns"; break;
case "Possibilità di vedere l'<i>inventario dei magazzini</i>":	$messaggio = "Possibilitat de veure el <i>inventari dels magatzems</i>"; break;
case "Possibilità di inserire nuovi magazzini":	$messaggio = "Possibilitat d'inserir nous magatzems"; break;
case "Possibilità di aggiungere e cancellare beni":	$messaggio = "Possibilitat d'afegir i esborrar béns"; break;
case "Solo in":  				$messaggio = "Només a"; break;
case "magazzini propri":  			$messaggio = "magatzems propis"; break;
case "magazzini dei suoi gruppi":  		$messaggio = "magatzems dels seus grups"; break;
case "Possibilità di modificare le quantità dei beni":	$messaggio = "Possibilitat de modificar l'estoc dels béns"; break;
case "non potrà vedere i <b>beni dell'inventario</b>":	$messaggio = "no podrà veure els <b>béns de l'inventari</b>"; break;
case "potrà vedere solo i <b>suoi beni dell'inventario</b>":	$messaggio = "podrà veure només <b>els seus propis béns de l'inventari</b>"; break;
case "potrà vedere i <b>beni dell'inventario</b>":	$messaggio = "podrà veure els <b>béns de l'inventari</b>"; break;
case "non potrà <b>inserire nuovi beni</b> nell'inventario":	$messaggio = "no podrà <b>inserir nous béns</b> a l'inventari"; break;
case "potrà <b>inserire nuovi beni</b> nell'inventario":	$messaggio = "podrà <b>inserir nous béns</b> a l'inventari"; break;
case "non potrà vedere <b>l'inventario":  	$messaggio = "no podrà veure l'<b>inventari"; break;
case "potrà vedere <b>l'inventario":  		$messaggio = "podrà veure l'<b>inventari"; break;
case "dei magazzini</b>":  			$messaggio = "dels magatzems</b>"; break;
case "solo dei suoi magazzini</b>":  		$messaggio = "només dels seus magatzems</b>"; break;
case "e di quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "i dels d'usuaris que pertanyin als seus grups"; break;
case "non potrà <b>inserire nuovi magazzini</b>":	$messaggio = "no podrà <b>inserir nous magatzems</b>"; break;
case "potrà <b>inserire nuovi magazzini</b>":	$messaggio = "podrà <b>inserir nous magatzems</b>"; break;
case "non potrà <b>aggiungere e cancellare beni</b>":	$messaggio = "no podrà <b>afegir ni esborrar béns</b>"; break;
case "potrà <b>aggiungere e cancellare beni</b>":	$messaggio = "podrà <b>afegir i esborrar béns</b>"; break;
case "nei magazzini":  				$messaggio = "als magatzems"; break;
case "solo nei suoi magazzini":  		$messaggio = "només als seus magatzems"; break;
case "e in quelli di utenti appartenenti ai suoi gruppi":	$messaggio = "i als d'usuaris que pertanyin als seus grups"; break;
case "non potrà <b>modificare le quantità dei beni</b>":	$messaggio = "no podrà <b>modificar la quantitat dels béns</b>"; break;
case "potrà <b>modificare le quantità dei beni</b>":	$messaggio = "podrà <b>modificar la quantitat dels béns</b>"; break;
case "creazione, download e cancellazione del backup completo":	$messaggio = "creació, descàrrega i esborrat de la còpia de seguretat"; break;
case "potrà creare i <b>backup</b>":  		$messaggio = "podrà crear <b>còpies de seguretat</b>"; break;
case "non potrà più creare i <b>backup</b>":  	$messaggio = "no podrà crear <b>còpies de seguretat</b>"; break;
case "Possibilità di vedere la <i>tabella con i documenti salvati</i>":	$messaggio = "Possibilitat de veure la <i>taula amb els documents desats</i>"; break;
case "Solo con documenti consentiti":  		$messaggio = "Solo con documents permeses"; break;
case "non potrà vedere la <b>tabella con i documenti salvati</b> del":	$messaggio = "no podrà veure la <b>taula amb els documents desats</b> del"; break;
case "potrà vedere solo i documenti a lui consentiti nella <b>tabella con i documenti salvati</b> del":	$messaggio = "podrà veure només documents que li siguin permesos a la <b>taula amb els documents desats</b> del"; break;
case "potrà vedere la <b>tabella con i documenti salvati</b> del":	$messaggio = "podrà veure la <b>taula amb els documents desats</b> del"; break;
case "Permetti l'uso solo delle <i>casse</i> selezionate":	$messaggio = "Permetre emprar només les <i>caixes</i> seleccionades"; break;
case "Permetti l'uso di tutte le <i>casse</i>":	$messaggio = "Permetre emprar totes les <i>caixes</i>"; break;
case "cassa principale":  			$messaggio = "caixa principal"; break;
case "potrà usare <b>tutte le casse</b>":  	$messaggio = "podrà emprar <b>totes les caixes</b>"; break;
case "potrà usare solo le <b>casse selezionate</b>":	$messaggio = "podrà emprar només les <b>caixes seleccionades</b>"; break;
case "Verranno cambiate le <b>casse</b> utilizzabili":	$messaggio = "Es canviaran les <b>caixes</b> utilizables"; break;
case "Inserire sempre i pagamenti delle prenotazioni nella cassa":	$messaggio = "Inserir sempre els pagaments de les reserves a la caixa"; break;
case "I pagamenti inseriti nelle prenotazioni dall'utente":	$messaggio = "Els pagaments inserits a les reserves per l'usuari"; break;
case "verranno anche registrati come entrate nella cassa chiamata":	$messaggio = "seràn enregistrats també com a ingressos a la caixa anomenada"; break;
case "non verranno registrati in cassa nel":	$messaggio = "no seran enregistrats a caixa al"; break;
case "nel":  					$messaggio = "al"; break;
case "Modifica dei documenti":  		$messaggio = "Modificar documents"; break;
case "potrà modificare i <b>documenti</b>":  	$messaggio = "podrà modificar els <b>documents</b>"; break;
case "non potrà più modificare i <b>documenti</b>":	$messaggio = "no podrà modificar els <b>documents</b>"; break;
case "Possibilità di vedere email, telefoni e fax dei clienti":	$messaggio = "Possibilitat de veure emails, telèfons i fax dels clients"; break;
case "Possibilità di vedere l'indirizzo dei clienti":	$messaggio = "Possibilitat de veure l'adreça dels clients"; break;
case "potrà vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "podrà veure <b>emails, telèfonos i fax</b> dels clients"; break;
case "non potrà più vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "no podrà veure <b>emails, telèfonos ni fax</b> dels clients"; break;
case "potrà vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "podrà veure <b>l'adreça</b> dels clients"; break;
case "non potrà più vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "ja no podrà veure <b>l'adreça</b> dels clients"; break;
case "e":  					$messaggio = "and"; break;
case "Privilegi Utenti":  			$messaggio = "Users Privileges"; break;
case "documento":  				$messaggio = "document"; break;
case "Possibilità di inserire il commento":  	$messaggio = "Possibility to insert the comment"; break;
case "Possibilità di inserire i commenti personalizzati":	$messaggio = "Possibility to insert custom comments"; break;
case "Possibilità di vedere il commento":  	$messaggio = "Possibility to view the comment"; break;
case "Possibilità di vedere e modificare i commenti personalizzati":	$messaggio = "Possibility to view and modify custom comments"; break;
case "verrà avvisato <b>sempre</b> quando inserirà prenotazioni nei periodi delle regole 1 del":	$messaggio = "will be <b>always</b> informed before inserting reservations in periods of rule 1 of"; break;
case "verrà avvisato solo quando inserirà prenotazioni nei periodi delle regole 1 <b>non selezionate</b> del":	$messaggio = "will be informed only when inserting reservations in periods of rule 1 <b>not selected</b> of"; break;
case "non verrà avvisato <b>mai</b> quando inserirà prenotazioni nei periodi delle regole 1 del":	$messaggio = "will <b>never</b> be informed when inserting reservations in periods of rule 1 of"; break;
case "non potrà inserire uno <b>sconto</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert a <b>discount</b> when inserts new reservations in"; break;
case "potrà inserire uno <b>sconto</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert a <b>discount</b> when inserts new reservations in"; break;
case "non potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>deposit</b> and the <b>commissions</b> when he inserts new reservations in"; break;
case "potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>deposit</b> and the <b>commissions</b> when he inserts new reservations in"; break;
case "non potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>extra costs</b> when inserts new reservations in"; break;
case "potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>extra costs</b> when inserts new reservations in"; break;
case "non potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>comment</b> when inserts new reservations in"; break;
case "potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>comment</b> when inserts new reservations in"; break;
case "non potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>custom comments</b> when inserts new reservations in"; break;
case "potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>custom comments</b> when inserts new reservations in"; break;
case "non potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>number of people</b> when he inserts new reservations in"; break;
case "potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>number of people</b> when he inserts new reservations in"; break;
case "non potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will not be able to view the <b>comment</b> of reservations in"; break;
case "potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will be able to view the <b>comment</b> of reservations in"; break;
case "non potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will not be able to view and modify <b>custom comments</b> of reservations in"; break;
case "potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will be able to view and modify <b>custom comments</b> of reservations in"; break;
case "potrà <b>cancellare</b> solo le prenotazioni non iniziate nel":	$messaggio = "will be able to <b>delete</b> only not begun reservations in"; break;
case "non potrà inserire l'<b>orario di entrata</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to change the <b>checkin hour</b> when inserts new reservations in"; break;
case "potrà inserire la l'<b>orario di entrata</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to change the <b>checkin hour</b> when inserts new reservations in"; break;
case "potrà inserire <b>l'origine della prenotazione</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>reservation origin</b> when inserts new reservations in"; break;
case "non potrà inserire <b>l'origine della prenotazione</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>reservation origin</b> when inserts new reservations in"; break;
case "Mostrare le prenotazioni non permesse come":	$messaggio = "Show not permitted reservations as"; break;
case "oscurate":  				$messaggio = "obscured"; break;
case "periodi vuoti":  				$messaggio = "empty periods"; break;
case "solo correnti e future":  		$messaggio = "only current and future"; break;
case "vedrà le prenotazioni non permesse come <em>oscurate</em>":	$messaggio = "will see not permitted reservations as <em>obscured</em>"; break;
case "vedrà le prenotazioni non permesse come <em>periodi vuoti</em>":	$messaggio = "will see not permitted reservations as <em>empty periods</em>"; break;
case "vedrà le prenotazioni non permesse come <em>periodi vuoti nel passato ed oscurate nel presente e nel futuro</em>":	$messaggio = "will see not permitted reservations as <em>empty periods in the past, obscured in the present and future</em>"; break;
case "Possibilità di cancellare o sovrascrivere i documenti salvati":	$messaggio = "Possibility to delete and overwrite saved documents"; break;
case "potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will be able to <b>delete and overwrite documents</b> saved in"; break;
case "non potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will not be able to <b>delete and overwrite documents</b> saved in"; break;
case "Creazione e modifica delle interconnessioni":	$messaggio = "Create and modify interconnections"; break;
case "potrà creare e modificare le <b>interconnessioni</b>":	$messaggio = "will be able to create and modify <b>interconnections</b>"; break;
case "non potrà più creare e modificare le <b>interconnessioni</b>":	$messaggio = "will not be able to create and modify <b>interconnections</b>"; break;
case "Modifica dei documenti come API":  	$messaggio = "Modify documents as API"; break;
case "potrà modificare i <b>documenti come API</b>":	$messaggio = "will be able to modify <b>documents as API</b>"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "questo può consentire l'accesso ai dati di tutte le prenotazioni":	$messaggio = "this can allow access to data of all reservations"; break;
case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "will not be able to modify <b>documents as API</b> anymore"; break;
case "Gestione della password per le carte di credito":	$messaggio = "Management of credit cards password"; break;
case "potrà gestire la <b>password per le carte di credito</b>":	$messaggio = "will be able to manage the <b>credit cards password</b>"; break;
case "non potrà più gestire la <b>password per le carte di credito</b>":	$messaggio = "will not be able to manage the <b>credit cards password</b>"; break;
case "senza mostrare il valore":  		$messaggio = "without showing the value"; break;
case "mostrando il valore":  			$messaggio = "showing the value"; break;
case "senza mostrare i valori":  		$messaggio = "without showing the values"; break;
case "mostrando i valori":  			$messaggio = "showing the values"; break;
case "Possibilità di modificare l'utente che ha inserito":	$messaggio = "Possibility to modify the inserting user"; break;
case "con tutti gli utenti":  			$messaggio = "with all users"; break;
case "solo con utenti dei suoi gruppi":  	$messaggio = "only with users from his groups"; break;
case "mostrando l'utente":  			$messaggio = "showing the user"; break;
case "senza mostrare l'utente":  		$messaggio = "without showing the user"; break;
case "potrà modificare l'<b>utente</b> che ha inserito la prenotazione nel":	$messaggio = "will be able to modify the <b>user</b> that inserted the reservation in"; break;
case "non potrà modificare l'<b>utente</b> che ha inserito la prenotazione nel":	$messaggio = "will not be able to modify the <b>user</b> that inserted the reservation in"; break;
case "senza mostrarla":  			$messaggio = "without showing it"; break;
case "senza mostrarli":  			$messaggio = "without showing them"; break;
case "Modifica delle tipologie di persone":  	$messaggio = "Modify people types"; break;
case "potrà modificare le sue <b>tipologie di persone</b>":	$messaggio = "will be able to modify his <b>people types</b>"; break;
case "non potrà più modificare le sue <b>tipologie di persone</b>":	$messaggio = "will not be able to modify his <b>people types</b>"; break;
case "Modifica delle valute":  			$messaggio = "Modify currencies"; break;
case "potrà modificare le sue <b>valute</b>":  	$messaggio = "will be able to modify his <b>currencies</b>"; break;
case "non potrà più modificare le sue <b>valute</b>":	$messaggio = "will not be able to modify his <b>currencies</b>"; break;
case "solo per lui":  				$messaggio = "only for him"; break;
case "anche per i suoi gruppi":  		$messaggio = "also for his groups"; break;
case "anche per tutti gli utenti":  		$messaggio = "also for all the users"; break;
case "e quelle di utenti appartenenti ai suoi gruppi":	$messaggio = "and the ones from users belonging to his groups"; break;
case "e quelle di tutti gli altri utenti":  	$messaggio = "and the ones from all users"; break;
case "Cancellare le prenotazioni in modo permanente":	$messaggio = "Delete reservations permanently"; break;
case "non <b>cancellerà mai in modo permanente</b> le prenotazioni nel":	$messaggio = "will <b>never permanently delete</b> reservations in"; break;
case "potrà scegliere se <b>cancellare in modo permanente</b> le prenotazioni nel":	$messaggio = "will choose if <b>permanently delete</b> reservations in"; break;
case "<b>cancellerà sempre in modo permanete</b> le prenotazioni nel":	$messaggio = "will <b>always permanently delete</b> reservations in"; break;
case "Possibilità di modificare le <i>regole di assegnazione</i>":	$messaggio = "Possibility to modify the <i>assignment rules</i>"; break;
case "non potrà modifcare le <b>regole di assegnazione 1</b> nel":	$messaggio = "will not be able to modify the <b>assignment rules 1</b> in"; break;
case "potrà modifcare le <b>regole di assegnazione 1</b> nel":	$messaggio = "will be able to modify the <b>assignment rules 1</b> in"; break;
case "non potrà modifcare le <b>regole di assegnazione 2 e 3</b> nel":	$messaggio = "will not be able to modify the <b>assignment rules 2 and 3</b> in"; break;
case "potrà modifcare le <b>regole di assegnazione 2 e 3</b> nel":	$messaggio = "will be able to modify the <b>assignment rules 2 and 3</b> in"; break;
case "assegnazione persone":  			$messaggio = "people assignment"; break;
case "Creazione e modifica delle pagine per il sito web":	$messaggio = "Create and modify website pages"; break;
case "Solo con i costi aggiuntivi":  		$messaggio = "only with extra costs"; break;
case "potrà creare e modificare le <b>pagine per il sito web</b>":	$messaggio = "will be able to create and modify <b>website pages</b>"; break;
case "potrà modificare le <b>pagine per il sito web</b> solo quando crea e modifica i costi aggiuntivi":	$messaggio = "will be able to modify <b>website pages</b> only when creating and modifying extra costs"; break;
case "non potrà più creare e modificare le <b>pagine per il sito web</b>":	$messaggio = "will not be able to create and modify <b>website pages</b>"; break;
case "solo per tariffe":  			$messaggio = "only for rates"; break;
case "per entrambi":  				$messaggio = "for both"; break;
case "Modifica dei documenti in formato HTML":	$messaggio = "Modify documents in HTML format"; break;
case "potrà modificare i <b>documenti con formato HTML</b>":	$messaggio = "will be able to modify <b>documents with HTML format</b>"; break;
case "non potrà più modificare i <b>documenti con formato HTML</b>":	$messaggio = "will not be able to modify <b>documents with HTML format</b> anymore"; break;
case "questo può consentire di portare attacchi di tipo \"Cross Site Scripting\" per rubare le credenziali di altri utenti":	$messaggio = "this could allow to carry out \"Cross Site Scripting\" attacks to steal other users' credentials"; break;
case "Modifica delle password":  		$messaggio = "Modify passwords"; break;
case "solo la propria":  			$messaggio = "only his own"; break;
case "potrà modificare solo la sua <b>password</b>":	$messaggio = "will be able to modify only his own <b>password</b>"; break;
case "non potrà più modificare le <b>password</b>":	$messaggio = "will not be able to modify <b>passwords</b>"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
